(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    766374,      17619]
NotebookOptionsPosition[    765237,      17591]
NotebookOutlinePosition[    765574,      17606]
CellTagsIndexPosition[    765531,      17603]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["readme", "Subsubsection",ExpressionUUID->"29c7a69c-6561-4a54-a5c0-599485cb274d"],

Cell["\<\
The final integrated two loop amplitudes for extracting the classical 3PM \
potential in deDonder, harmonic and simplified gauges are given below up to \
6PN. We have omitted a factor of log[q]. They are functions of

E[a] = energy of particle a
m[a] = mass of particle a
p = center of mass momentum
\[Sigma] = (E[1]E[2]+p^2)/(m[1]m[2])

The format is  \
{{graph1,graph1b},{graph2,graph2b},{graph4,graph4b},graph5,{graph7,graph7b}}  \
where graphXb is the contribution from the nonplanar, twisted version of \
graphX.

The integrands can be found in Integrands.nb attached with this paper.\
\>", "Text",
 CellChangeTimes->{
  3.7934402752721786`*^9, {3.7934403163829527`*^9, 3.7934403166932163`*^9}, {
   3.793440554109964*^9, 3.793440653973922*^9}, {3.79344070749896*^9, 
   3.793440745633889*^9}, {3.793440905445696*^9, 3.793441012386775*^9}, {
   3.793442785597466*^9, 3.793442789960527*^9}, {3.793540515197806*^9, 
   3.7935405442145233`*^9}, {3.7935407431744413`*^9, 
   3.7935407436649313`*^9}},ExpressionUUID->"802ea981-f6ca-46fd-8863-\
edda4aa8ea49"]
}, Open  ]],

Cell[CellGroupData[{

Cell["deDonder", "Subsubsection",
 CellChangeTimes->{{3.7934407791993437`*^9, 
  3.793440780714941*^9}},ExpressionUUID->"507a8c47-6125-4b43-8750-\
b07a1410f3c4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"outD", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SeriesData", "[", 
        RowBox[{"p", ",", "0", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"16", "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "3"}], "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                   "-", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "4"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"15", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                   "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], ")"}]}], "+", 
                RowBox[{"4", "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"165", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                   "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "-", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], ")"}]}], "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"70", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "6"}]}], "+", 
                   RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                   RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "-", 
                   RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{"5", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"15", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"1953", "*", "\[Sigma]", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{"m", "[", "1", "]"}], "*", 
                  RowBox[{"m", "[", "2", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "-", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], ")"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], ")"}]}], "+", 
                 RowBox[{"64", "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "7"}], "+", 
                    RowBox[{"98", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "8"}]}], "+", 
                    RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                    RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "-", 
                    RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                    RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "-", 
                    RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                    RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "+", 
                    RowBox[{"7", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}]}], ")"}]}]}], ")"}]}], ")"}]}], "/", 
            RowBox[{"(", 
             RowBox[{"84", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"1737", "*", "\[Sigma]", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{"m", "[", "1", "]"}], "*", 
                  RowBox[{"m", "[", "2", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}],
                     "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "-", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "10"}]}], ")"}]}], "+", 
                 RowBox[{"128", "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"42", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "10"}]}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}], "+", 
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "10"}]}]}], ")"}]}]}], ")"}]}], ")"}]}], "/", 
            RowBox[{"(", 
             RowBox[{"72", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "11"}], "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "11"}]}], 
             ")"}]}]}], "}"}], ",", "0", ",", "9", ",", "1"}], "]"}], ",", 
       RowBox[{"SeriesData", "[", 
        RowBox[{"p", ",", "0", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "2"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "4"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"5", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}]}], 
                "+", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "-", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
                "+", 
                RowBox[{"5", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "6"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"15", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"7", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}]}], 
                "+", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "-", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
                "-", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
                "+", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
                "+", 
                RowBox[{"7", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "8"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"21", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}]}],
                 "+", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "-", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
                "-", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
                "+", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
                "-", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
                "+", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
                "+", 
                RowBox[{"3", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "10"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"9", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}], "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "10"}]}], 
             ")"}]}]}], "}"}], ",", "0", ",", "9", ",", "1"}], "]"}]}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SeriesData", "[", 
        RowBox[{"p", ",", "0", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "64"}], "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}], 
                "-", 
                RowBox[{"16", "*", "\[Sigma]", "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "7"}], "+", 
                    RowBox[{"16", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], ")"}]}],
                 "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "-", 
                    RowBox[{"3", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], ")"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}]}],
                   ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], "*", 
              
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"m", "[", "1", "]"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"128", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "3"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], ")"}]}], 
                   "+", 
                   RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], ")"}]}],
                 "+", 
                RowBox[{
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"128", "*", "\[Sigma]", "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "3"}]}], "+", 
                   RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"15", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "-", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}]}],
                     ")"}]}], "+", 
                   RowBox[{"32", "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{"m", "[", "2", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "3"}]}], "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], ")"}]}]}], ")"}]}], "-", 
                   RowBox[{"32", "*", "\[Sigma]", "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "3"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "7"}], "+", 
                    RowBox[{"16", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "4"}]}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "13"}], "+", 
                    RowBox[{"31", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
             ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"9", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}], "*", 
              
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"m", "[", "1", "]"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "3"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "3"}], "*", "\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "+", 
                    RowBox[{"4", "*", "\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                   RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "+", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}]}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"512", "*", "\[Sigma]", "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "3"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}], "+", 
                   RowBox[{"15", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"66", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"51", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                    RowBox[{"19", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], 
                    ")"}]}]}], ")"}]}], "-", 
                   RowBox[{"128", "*", "\[Sigma]", "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"10", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "8"}]}], "+", 
                    RowBox[{"30", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                    RowBox[{"15", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "7"}], "+", 
                    RowBox[{"16", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "20"}], "+", 
                    RowBox[{"47", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}]}], ")"}]}], "+", 
                   RowBox[{"128", "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{"m", "[", "2", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "3"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}], "-", 
                    RowBox[{"12", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], 
            "/", 
            RowBox[{"(", 
             RowBox[{"180", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}], "*", 
              
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"m", "[", "1", "]"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2048", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "5"}], "*", "\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "8"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "-", 
                    RowBox[{"7", "*", "\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"7", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "-", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                   RowBox[{"5", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7", "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "-", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "+", 
                   RowBox[{"15", "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}]}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2048", "*", "\[Sigma]", "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "7"}]}], "+", 
                    RowBox[{"7", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"7", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}]}], ")"}]}], "+", 
                   RowBox[{"35", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"279", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"151", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                    RowBox[{"87", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], 
                    ")"}]}]}], ")"}]}], "-", 
                   RowBox[{"2560", "*", "\[Sigma]", "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "10"}]}], "+", 
                    RowBox[{"21", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "+", 
                    RowBox[{"7", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "7"}], "+", 
                    RowBox[{"16", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "+", 
                    RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "27"}], "+", 
                    RowBox[{"63", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "+", 
                    RowBox[{"7", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}]}], ")"}]}], "+", 
                   RowBox[{"512", "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{"m", "[", "2", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "3"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "4"}]}], "-", 
                    RowBox[{"8", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"9", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}]}], ")"}]}], "-", 
                    RowBox[{"20", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], 
            "/", 
            RowBox[{"(", 
             RowBox[{"1680", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}], "*", 
              
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"m", "[", "1", "]"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"8192", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "7"}], "*", "\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "10"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "-", 
                    RowBox[{"9", "*", "\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"9", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "-", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "+", 
                   RowBox[{"7", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9", "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "-", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}], "+", 
                   RowBox[{"28", "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "10"}]}]}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"8192", "*", "\[Sigma]", "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "9"}]}], "+", 
                    RowBox[{"9", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"9", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "+", 
                    RowBox[{"7", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}]}], ")"}]}], "+", 
                   RowBox[{"63", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1158", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1615", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                    RowBox[{"1103", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], 
                    ")"}]}]}], ")"}]}], "-", 
                   RowBox[{"14336", "*", "\[Sigma]", "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"12", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "12"}]}], "+", 
                    RowBox[{"36", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "11"}],
                     "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "10"}]}], "+", 
                    RowBox[{"9", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}],
                     "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "7"}], "+", 
                    RowBox[{"16", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "34"}], "+", 
                    RowBox[{"79", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}]}], ")"}]}], "+", 
                   RowBox[{"2048", "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{"m", "[", "2", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "28"}], "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                    "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}], ")"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "9"}]}], "+", 
                    RowBox[{"9", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"9", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "+", 
                    RowBox[{"7", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
             ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"12096", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "11"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}], 
             ")"}]}]}], "}"}], ",", "0", ",", "9", ",", "1"}], "]"}], ",", 
       RowBox[{"SeriesData", "[", 
        RowBox[{"p", ",", "0", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"16", "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}]}], 
                "-", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"\[Sigma]", "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], 
                  ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"16", "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"m", "[", "1", "]"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"4", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "2"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], ")"}]}], 
                   "+", 
                   RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], ")"}]}],
                 "+", 
                RowBox[{
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"4", "*", "\[Sigma]", "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}]}], "+", 
                   RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}], 
                   "+", 
                   RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{"m", "[", "2", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}]}], ")"}]}], "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "-", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], ")"}]}]}], ")"}]}], "+", 
                   RowBox[{"\[Sigma]", "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
             ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"9", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"16", "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"m", "[", "1", "]"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"4", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "2"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "3"}], "*", "\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "+", 
                    RowBox[{"4", "*", "\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                   RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "+", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}]}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"15", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], ")"}]}],
                    "+", 
                   RowBox[{"4", "*", "\[Sigma]", "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}], "+", 
                   RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{"m", "[", "2", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}], ")"}]}], "-", 
                    RowBox[{"12", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], ")"}]}]}], ")"}]}], "+", 
                   RowBox[{"\[Sigma]", "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"20", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}]}], "+", 
                    RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"10", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "5"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
             ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"45", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"16", "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"m", "[", "1", "]"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"4", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "2"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "5"}], "*", "\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "+", 
                    RowBox[{"8", "*", "\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                   RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "+", 
                    RowBox[{"3", "*", "\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"4", "*", "\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "-", 
                   RowBox[{"5", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{"15", "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}]}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"35", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                    RowBox[{"3", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], ")"}]}],
                    "+", 
                   RowBox[{"4", "*", "\[Sigma]", "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "4"}]}], "-", 
                    RowBox[{"8", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"9", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}]}], ")"}]}], "+", 
                   RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{"m", "[", "2", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "4"}]}], "-", 
                    RowBox[{"8", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"9", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}]}], ")"}]}], ")"}]}], "-", 
                    RowBox[{"20", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "-", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], ")"}]}]}], ")"}]}], "+", 
                   RowBox[{"5", "*", "\[Sigma]", "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"14", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"14", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "7"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
             ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"105", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"16", "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"m", "[", "1", "]"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"4", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "2"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "7"}], "*", "\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "7"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "+", 
                    RowBox[{"12", "*", "\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                   RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "+", 
                    RowBox[{"5", "*", "\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"8", "*", "\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "-", 
                   RowBox[{"5", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"3", "*", "\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"4", "*", "\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "-", 
                   RowBox[{"7", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                   RowBox[{"28", "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}]}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"63", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], ")"}]}],
                    "+", 
                   RowBox[{"4", "*", "\[Sigma]", "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "6"}]}], "-", 
                    RowBox[{"12", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"15", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{"16", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{"15", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "-", 
                    RowBox[{"12", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                    RowBox[{"7", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}]}], ")"}]}], "+", 
                   RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{"m", "[", "2", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "28"}], "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "-", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], ")"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], ")"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "6"}]}], "-", 
                    RowBox[{"12", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"15", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{"16", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{"15", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "-", 
                    RowBox[{"12", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                    RowBox[{"7", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}]}], ")"}]}]}], ")"}]}], "+", 
                   RowBox[{"7", "*", "\[Sigma]", "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"24", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"18", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "9"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
             ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"189", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "11"}]}], 
             ")"}]}]}], "}"}], ",", "0", ",", "9", ",", "1"}], "]"}]}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SeriesData", "[", 
        RowBox[{"p", ",", "0", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"8", "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                   "-", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], ")"}]}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"25", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"25", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"15", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                   "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], ")"}]}], "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"25", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"25", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"165", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                   "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "-", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], ")"}]}], "+", 
                RowBox[{"16", "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"5", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"25", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "6"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{"5", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"25", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"15", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"1953", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                   "-", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], ")"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                   "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], ")"}]}], "+", 
                RowBox[{"128", "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"7", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"25", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "8"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "+", 
                   RowBox[{"7", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"25", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"168", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "1536"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "11"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                RowBox[{"19200", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "11"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "-", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "-", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
                "-", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
                "-", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
                "+", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
                "+", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
                "-", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
                "-", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
                "+", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
                "+", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
                "-", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
                "-", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "10"}]}],
                 "+", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "10"}]}],
                 "-", 
                RowBox[{"1536", "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "11"}]}],
                 "+", 
                RowBox[{"19200", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "11"}]}],
                 "+", 
                RowBox[{"1737", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}],
                    "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "-", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "10"}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"144", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "11"}], "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "11"}]}], 
             ")"}]}]}], "}"}], ",", "0", ",", "9", ",", "1"}], "]"}], ",", 
       RowBox[{"SeriesData", "[", 
        RowBox[{"p", ",", "0", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "2"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "4"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "5"}], "+", 
                   RowBox[{"70", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}]}], 
                "+", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "-", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
                "+", 
                RowBox[{"5", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "6"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"15", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "7"}], "+", 
                   RowBox[{"98", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}]}], 
                "+", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "-", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
                "-", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
                "+", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
                "+", 
                RowBox[{"7", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "8"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"21", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", 
                   RowBox[{"42", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}]}],
                 "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "-", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
                "-", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
                "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
                "-", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
                "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
                "+", 
                RowBox[{"3", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "10"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"9", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}], "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "10"}]}], 
             ")"}]}]}], "}"}], ",", "0", ",", "9", ",", "1"}], "]"}]}], "}"}],
      ",", 
     RowBox[{"SeriesData", "[", 
      RowBox[{"p", ",", "0", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"16", "*", 
            RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
            RowBox[{
             RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
            RowBox[{
             RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"4", "*", 
                  RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
              RowBox[{"\[Sigma]", "*", 
               RowBox[{"m", "[", "1", "]"}], "*", 
               RowBox[{"m", "[", "2", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"6", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], ")"}]}]}],
              ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"3", "*", 
            RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
           ")"}]}], ",", "0", ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "16"}], "*", 
            RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
            RowBox[{"m", "[", "1", "]"}], "*", 
            RowBox[{
             RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                   "^", "2"}]}], "-", 
                 RowBox[{"3", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "-", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"\[Sigma]", "*", 
               RowBox[{"m", "[", "2", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"6", "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                   "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"18", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"9", "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
           ")"}]}], ",", "0", ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "16"}], "*", 
            RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
            RowBox[{"m", "[", "1", "]"}], "*", 
            RowBox[{
             RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"60", "*", "\[Sigma]", "*", 
               RowBox[{"m", "[", "2", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}]}], 
              "+", 
              RowBox[{"120", "*", "\[Sigma]", "*", 
               RowBox[{"m", "[", "2", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
              RowBox[{"3", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", "*", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                  RowBox[{"m", "[", "1", "]"}]}], "+", 
                 RowBox[{"\[Sigma]", "*", 
                  RowBox[{"(", 
                   RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{"m", "[", "2", "]"}]}]}], ")"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
              "+", 
              RowBox[{"3", "*", 
               RowBox[{"m", "[", "1", "]"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "2"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", "*", 
                  RowBox[{"m", "[", "1", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}]}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "2"}]}]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", "*", 
                  RowBox[{"m", "[", "1", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}]}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "2"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", "*", 
                  RowBox[{"m", "[", "1", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}]}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "2"}]}]}], ")"}]}], "+", 
              RowBox[{"3", "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"30", "*", "\[Sigma]", "*", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                  RowBox[{"m", "[", "2", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"20", "*", "\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "2"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"45", "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
           ")"}]}], ",", "0", ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "16"}], "*", 
            RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
            RowBox[{"m", "[", "1", "]"}], "*", 
            RowBox[{
             RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"210", "*", "\[Sigma]", "*", 
               RowBox[{"m", "[", "2", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}]}], 
              "+", 
              RowBox[{"420", "*", "\[Sigma]", "*", 
               RowBox[{"m", "[", "2", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
              RowBox[{"5", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", "*", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                  RowBox[{"m", "[", "1", "]"}]}], "+", 
                 RowBox[{"\[Sigma]", "*", 
                  RowBox[{"(", 
                   RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{"m", "[", "2", "]"}]}]}], ")"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
              "+", 
              RowBox[{"5", "*", 
               RowBox[{"m", "[", "1", "]"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "2"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"5", "*", 
                  RowBox[{"m", "[", "1", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}]}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "2"}]}]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"5", "*", 
                  RowBox[{"m", "[", "1", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}]}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "2"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"5", "*", 
                  RowBox[{"m", "[", "1", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}]}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "2"}]}]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"5", "*", 
                  RowBox[{"m", "[", "1", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}]}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "2"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"5", "*", 
                  RowBox[{"m", "[", "1", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}]}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "2"}]}]}], ")"}]}], "+", 
              RowBox[{"5", "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"42", "*", "\[Sigma]", "*", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                  RowBox[{"m", "[", "2", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"42", "*", "\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "2"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"105", "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
           ")"}]}], ",", "0", ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "16"}], "*", 
            RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
            RowBox[{"m", "[", "1", "]"}], "*", 
            RowBox[{
             RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"504", "*", "\[Sigma]", "*", 
               RowBox[{"m", "[", "2", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "11"}]}], 
              "+", 
              RowBox[{"1008", "*", "\[Sigma]", "*", 
               RowBox[{"m", "[", "2", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}], 
               "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
              RowBox[{"7", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", "*", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                  RowBox[{"m", "[", "1", "]"}]}], "+", 
                 RowBox[{"\[Sigma]", "*", 
                  RowBox[{"(", 
                   RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{"m", "[", "2", "]"}]}]}], ")"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
              "+", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"7", "*", 
                  RowBox[{"m", "[", "1", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"2", "-", 
                    RowBox[{"12", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "2"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"7", "*", 
                  RowBox[{"m", "[", "1", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"2", "-", 
                    RowBox[{"12", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "2"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"7", "*", 
                  RowBox[{"m", "[", "1", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"2", "-", 
                    RowBox[{"12", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "2"}]}]}], ")"}]}], "+", 
              RowBox[{"7", "*", 
               RowBox[{"m", "[", "1", "]"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "2"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"7", "*", 
                  RowBox[{"m", "[", "1", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}]}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "2"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"7", "*", 
                  RowBox[{"m", "[", "1", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}]}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "2"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"7", "*", 
                  RowBox[{"m", "[", "1", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}]}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "2"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"7", "*", 
                  RowBox[{"m", "[", "1", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"\[Sigma]", "*", 
                    RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}]}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "2"}]}]}], ")"}]}], "+", 
              RowBox[{"7", "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"54", "*", "\[Sigma]", "*", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                  RowBox[{"m", "[", "2", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}]}], "+", 
                    RowBox[{"72", "*", "\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "2"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"189", "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "10"}]}], 
           ")"}]}]}], "}"}], ",", "0", ",", "9", ",", "1"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"16", "*", 
          RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", "*", 
              RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "^", "2"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ArcSinh", "[", 
             RowBox[{"p", "/", 
              RowBox[{"m", "[", "1", "]"}]}], "]"}], "+", 
            RowBox[{"ArcSinh", "[", 
             RowBox[{"p", "/", 
              RowBox[{"m", "[", "2", "]"}]}], "]"}]}], ")"}], "*", 
          RowBox[{
           RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
          RowBox[{
           RowBox[{"m", "[", "2", "]"}], "^", "4"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"p", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
            RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}], ")"}]}], 
       ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"16", "*", 
          RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", "*", 
              RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "^", "2"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ArcSinh", "[", 
             RowBox[{"p", "/", 
              RowBox[{"m", "[", "1", "]"}]}], "]"}], "+", 
            RowBox[{"ArcSinh", "[", 
             RowBox[{"p", "/", 
              RowBox[{"m", "[", "2", "]"}]}], "]"}]}], ")"}], "*", 
          RowBox[{
           RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
          RowBox[{
           RowBox[{"m", "[", "2", "]"}], "^", "4"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"p", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
            RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}], 
         ")"}]}]}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.793440811318199*^9, 3.793440891883203*^9}, 
   3.793442052304179*^9, {3.793442118801029*^9, 3.793442124382099*^9}, {
   3.793442474358585*^9, 
   3.7934425017082157`*^9}},ExpressionUUID->"28a02281-ac94-4bfa-aa89-\
463b0cddc958"]
}, Closed]],

Cell[CellGroupData[{

Cell["harmonic", "Subsubsection",
 CellChangeTimes->{{3.7934407837215633`*^9, 
  3.793440784856797*^9}},ExpressionUUID->"8cdeed82-5ad7-4c21-a90b-\
3e7cdc63ee0c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"outH", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SeriesData", "[", 
        RowBox[{"p", ",", "0", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"16", "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "3"}], "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                   "-", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "4"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"15", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                   "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], ")"}]}], "+", 
                RowBox[{"4", "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"165", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                   "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "-", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], ")"}]}], "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"70", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "6"}]}], "+", 
                   RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                   RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "-", 
                   RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{"5", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"15", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"1953", "*", "\[Sigma]", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{"m", "[", "1", "]"}], "*", 
                  RowBox[{"m", "[", "2", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "-", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], ")"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], ")"}]}], "+", 
                 RowBox[{"64", "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "7"}], "+", 
                    RowBox[{"98", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "8"}]}], "+", 
                    RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                    RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "-", 
                    RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                    RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "-", 
                    RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                    RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "+", 
                    RowBox[{"7", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}]}], ")"}]}]}], ")"}]}], ")"}]}], "/", 
            RowBox[{"(", 
             RowBox[{"84", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"1737", "*", "\[Sigma]", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{"m", "[", "1", "]"}], "*", 
                  RowBox[{"m", "[", "2", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}],
                     "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "-", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "10"}]}], ")"}]}], "+", 
                 RowBox[{"128", "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"42", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "10"}]}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}], "+", 
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "10"}]}]}], ")"}]}]}], ")"}]}], ")"}]}], "/", 
            RowBox[{"(", 
             RowBox[{"72", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "11"}], "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "11"}]}], 
             ")"}]}]}], "}"}], ",", "0", ",", "9", ",", "1"}], "]"}], ",", 
       RowBox[{"SeriesData", "[", 
        RowBox[{"p", ",", "0", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "2"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "4"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"5", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}]}], 
                "+", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "-", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
                "+", 
                RowBox[{"5", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "6"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"15", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"7", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}]}], 
                "+", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "-", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
                "-", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
                "+", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
                "+", 
                RowBox[{"7", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "8"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"21", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}]}],
                 "+", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "-", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
                "-", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
                "+", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
                "-", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
                "+", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
                "+", 
                RowBox[{"3", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "10"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"9", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}], "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "10"}]}], 
             ")"}]}]}], "}"}], ",", "0", ",", "9", ",", "1"}], "]"}]}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SeriesData", "[", 
        RowBox[{"p", ",", "0", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "16"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"64", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"192", "*", 
                 RowBox[{"\[Sigma]", "^", "4"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"256", "*", 
                 RowBox[{"\[Sigma]", "^", "4"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "+", 
                RowBox[{"16", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "-", 
                RowBox[{"64", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"64", "*", 
                 RowBox[{"\[Sigma]", "^", "4"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"16", "*", "\[Sigma]", "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "-", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], ")"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}], 
                "-", 
                RowBox[{"16", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"4", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Sigma]", "^", "2"}], "+", 
                    RowBox[{"\[Sigma]", "^", "4"}]}], ")"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}], 
                "-", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"6", "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], 
                    ")"}]}]}], ")"}]}], "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}], 
                   "+", 
                   RowBox[{"8", "*", "\[Sigma]", "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{"m", "[", "2", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"3", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], ")"}]}],
                    "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}]}],
                     ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], "*", 
              
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"m", "[", "1", "]"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"128", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "3"}]}], "+", 
                RowBox[{"128", "*", "\[Sigma]", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "3"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], ")"}]}],
                 "-", 
                RowBox[{"32", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"4", "-", 
                    RowBox[{"12", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}], "+", 
                    RowBox[{"16", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}]}], ")"}]}], "-", 
                RowBox[{"3", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"15", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "-", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"39", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                    RowBox[{"15", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], 
                    ")"}]}]}], ")"}]}], "-", 
                RowBox[{"32", "*", "\[Sigma]", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "3"}]}], ")"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "7"}], "+", 
                    RowBox[{"16", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "4"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "27"}], "+", 
                    RowBox[{"64", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"9", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}], "*", 
              
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"m", "[", "1", "]"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "3"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                   "-", 
                   RowBox[{"3", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}], "+", 
                RowBox[{"512", "*", "\[Sigma]", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "3"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"12", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}]}], ")"}]}], "-", 
                RowBox[{"384", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "6"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"20", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}], "+", 
                    RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{"5", "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}]}], ")"}]}], "+", 
                RowBox[{"15", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"66", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"243", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                    RowBox[{"147", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], 
                    ")"}]}]}], ")"}]}], "-", 
                RowBox[{"128", "*", "\[Sigma]", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "10"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "8"}]}], "-", 
                   RowBox[{"30", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "41"}], "+", 
                    RowBox[{"96", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "-", 
                    RowBox[{"10", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}], "+", 
                   RowBox[{"15", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "7"}], "+", 
                    RowBox[{"16", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "-", 
                    RowBox[{"2", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"180", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}], "*", 
              
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"m", "[", "1", "]"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2048", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "3"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                   "-", 
                   RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{"10", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{"15", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}]}], ")"}]}], "+", 
                RowBox[{"2048", "*", "\[Sigma]", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"5", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "8"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"9", "-", 
                    RowBox[{"18", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"7", "*", 
                    RowBox[{"(", 
                    RowBox[{"7", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                   RowBox[{"5", "*", 
                    RowBox[{"(", 
                    RowBox[{"15", "-", 
                    RowBox[{"30", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "+", 
                   RowBox[{"30", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}]}], ")"}]}], "-", 
                RowBox[{"2560", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "8"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"8", "-", 
                    RowBox[{"28", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}], "+", 
                    RowBox[{"32", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "+", 
                   RowBox[{"7", "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}]}], ")"}]}], "+", 
                RowBox[{"35", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"279", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"663", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                    RowBox[{"471", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], 
                    ")"}]}]}], ")"}]}], "-", 
                RowBox[{"2560", "*", "\[Sigma]", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "7"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "10"}]}], "-", 
                   RowBox[{"21", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "55"}], "+", 
                    RowBox[{"128", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "-", 
                    RowBox[{"7", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}], "+", 
                   RowBox[{"7", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "7"}], "+", 
                    RowBox[{"16", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "-", 
                    RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"1680", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}], "*", 
              
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"m", "[", "1", "]"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"8192", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "3"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                   "-", 
                   RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{"10", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{"15", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "-", 
                   RowBox[{"21", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{"28", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}]}], ")"}]}], "+", 
                RowBox[{"8192", "*", "\[Sigma]", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"7", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "10"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"11", "-", 
                    RowBox[{"22", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"9", "*", 
                    RowBox[{"(", 
                    RowBox[{"9", "-", 
                    RowBox[{"18", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "+", 
                   RowBox[{"7", "*", 
                    RowBox[{"(", 
                    RowBox[{"19", "-", 
                    RowBox[{"38", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}], "+", 
                   RowBox[{"56", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "10"}]}]}], ")"}]}], "-", 
                RowBox[{"14336", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "10"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"10", "-", 
                    RowBox[{"36", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}], "+", 
                    RowBox[{"40", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}], "+", 
                   RowBox[{"9", "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "10"}]}]}], ")"}]}], "+", 
                RowBox[{"63", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"1158", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"6735", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                    RowBox[{"5199", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], 
                    ")"}]}]}], ")"}]}], "-", 
                RowBox[{"14336", "*", "\[Sigma]", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "12"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "12"}]}], "-", 
                   RowBox[{"36", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "11"}],
                     "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "10"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "69"}], "+", 
                    RowBox[{"160", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "-", 
                    RowBox[{"12", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}], "+", 
                   RowBox[{"9", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}],
                     "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "7"}], "+", 
                    RowBox[{"16", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "-", 
                    RowBox[{"4", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"12096", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}], "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "11"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}], 
             ")"}]}]}], "}"}], ",", "0", ",", "9", ",", "1"}], "]"}], ",", 
       RowBox[{"SeriesData", "[", 
        RowBox[{"p", ",", "0", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"16", "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "^", "2"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], ")"}]}],
                 "+", 
                RowBox[{"2", "*", "\[Sigma]", "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], 
                  ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"16", "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"m", "[", "1", "]"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"4", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "2"}]}], "+", 
                RowBox[{"4", "*", "\[Sigma]", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "2"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], ")"}]}],
                 "+", 
                RowBox[{
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}]}], ")"}]}], "+", 
                RowBox[{"2", "*", "\[Sigma]", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}]}], ")"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"9", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"m", "[", "1", "]"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"16", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "2"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                   "-", 
                   RowBox[{"3", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}], "-", 
                RowBox[{"3", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "4"}], "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                   RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "-", 
                   RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{"5", "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}]}], ")"}]}], "-", 
                RowBox[{"4", "*", "\[Sigma]", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"9", "-", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{"4", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                   RowBox[{"4", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"4", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"10", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{"12", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}]}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"8", "*", "\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}], "-", 
                   RowBox[{"4", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "-", 
                    RowBox[{"3", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}], "+", 
                   RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "^", "2"}], 
                    "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], ")"}]}]}], ")"}]}], "+", 
                RowBox[{"2", "*", "\[Sigma]", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"10", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}]}], "-", 
                   RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "5"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"45", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"m", "[", "1", "]"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"16", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "2"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                   "-", 
                   RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{"10", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{"15", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}]}], ")"}]}], "-", 
                RowBox[{"5", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "4"}], "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "7"}]}], "+", 
                   RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                   RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "-", 
                   RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "-", 
                   RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                   RowBox[{"7", "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}]}], ")"}]}], "-", 
                RowBox[{"4", "*", "\[Sigma]", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"5", "*", 
                    RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "7"}]}], "+", 
                   RowBox[{"4", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                   RowBox[{"4", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"4", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "-", 
                   RowBox[{"4", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{"4", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{"5", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                   RowBox[{"30", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}]}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"8", "*", "\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "4"}]}], "-", 
                    RowBox[{"8", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"9", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}]}], ")"}]}], "-", 
                   RowBox[{"4", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "-", 
                    RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{"10", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{"15", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}]}], ")"}]}], "+", 
                   RowBox[{"5", "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "^", "2"}], 
                    "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "-", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], ")"}]}]}], ")"}]}], "-", 
                RowBox[{"10", "*", "\[Sigma]", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "7"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "7"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"105", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"m", "[", "1", "]"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "4"}], "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{"16", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"4", "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{"16", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "-", 
                   RowBox[{"4", "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "-", 
                   RowBox[{"16", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{"4", "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{"16", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "-", 
                   RowBox[{"4", "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "-", 
                   RowBox[{"16", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                   RowBox[{"4", "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "+", 
                   RowBox[{"16", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "-", 
                   RowBox[{"4", "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "-", 
                   RowBox[{"16", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "-", 
                   RowBox[{"140", "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}], "-", 
                   RowBox[{"560", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}], "-", 
                   RowBox[{"112", "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "10"}]}], "-", 
                   RowBox[{"448", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "10"}]}], "+", 
                   RowBox[{"7", "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "^", "2"}], 
                    "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "-", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], ")"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], ")"}]}], "+", 
                   RowBox[{"8", "*", "\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "6"}]}], "-", 
                    RowBox[{"12", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"15", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{"16", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{"15", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "-", 
                    RowBox[{"12", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                    RowBox[{"7", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}]}], ")"}]}]}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "7"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Sigma]", "^", "2"}], "+", 
                    RowBox[{"\[Sigma]", "^", "4"}]}], ")"}]}]}], ")"}], "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "-", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], ")"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], ")"}]}], "-", 
                   RowBox[{"8", "*", "\[Sigma]", "*", 
                    RowBox[{"m", "[", "2", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "6"}]}], "-", 
                    RowBox[{"12", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"15", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{"16", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{"15", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "-", 
                    RowBox[{"12", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                    RowBox[{"7", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}]}], ")"}]}], "+", 
                   RowBox[{"16", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"m", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "-", 
                    RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{"10", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{"15", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "-", 
                    RowBox[{"21", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                    RowBox[{"28", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}]}], ")"}]}]}], ")"}]}], "+", 
                RowBox[{"7", "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"4", "*", "\[Sigma]", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                    "-", 
                    RowBox[{"9", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "-", 
                    RowBox[{"8", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}]}], ")"}]}], "-", 
                   RowBox[{"2", "*", "\[Sigma]", "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "12"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "9"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}]}], ")"}]}]}], ")"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                    RowBox[{"m", "[", "2", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "-", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], ")"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], ")"}]}], ")"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "-", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], ")"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], ")"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "-", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], ")"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
               ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"189", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}], "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "10"}]}], 
             ")"}]}]}], "}"}], ",", "0", ",", "9", ",", "1"}], "]"}]}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SeriesData", "[", 
        RowBox[{"p", ",", "0", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"8", "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                   "-", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], ")"}]}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"25", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"25", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"15", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                   "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], ")"}]}], "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"25", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"25", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"165", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                   "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "-", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], ")"}]}], "+", 
                RowBox[{"16", "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"5", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"25", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "6"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{"5", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"25", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"15", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"1953", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                   "-", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], ")"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                   "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], ")"}]}], "+", 
                RowBox[{"128", "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"7", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"25", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "8"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "+", 
                   RowBox[{"7", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"25", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"168", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "1536"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "11"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                RowBox[{"19200", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "11"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "-", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "-", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
                "-", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
                "-", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
                "+", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
                "+", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
                "-", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
                "-", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
                "+", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
                "+", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
                "-", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
                "-", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "10"}]}],
                 "+", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "10"}]}],
                 "-", 
                RowBox[{"1536", "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "11"}]}],
                 "+", 
                RowBox[{"19200", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "11"}]}],
                 "+", 
                RowBox[{"1737", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}],
                    "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "-", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "10"}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"144", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "11"}], "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "11"}]}], 
             ")"}]}]}], "}"}], ",", "0", ",", "9", ",", "1"}], "]"}], ",", 
       RowBox[{"SeriesData", "[", 
        RowBox[{"p", ",", "0", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "2"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "4"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "5"}], "+", 
                   RowBox[{"70", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}]}], 
                "+", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "-", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
                "+", 
                RowBox[{"5", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "6"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"15", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "7"}], "+", 
                   RowBox[{"98", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}]}], 
                "+", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "-", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
                "-", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
                "+", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
                "+", 
                RowBox[{"7", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "8"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"21", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", 
                   RowBox[{"42", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}]}],
                 "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "-", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
                "-", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
                "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
                "-", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
                "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
                "+", 
                RowBox[{"3", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "10"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"9", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}], "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "10"}]}], 
             ")"}]}]}], "}"}], ",", "0", ",", "9", ",", "1"}], "]"}]}], "}"}],
      ",", 
     RowBox[{"SeriesData", "[", 
      RowBox[{"p", ",", "0", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"16", "*", 
            RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
            RowBox[{
             RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
            RowBox[{
             RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"12", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], ")"}]}], 
              "+", 
              RowBox[{"2", "*", "\[Sigma]", "*", 
               RowBox[{"m", "[", "1", "]"}], "*", 
               RowBox[{"m", "[", "2", "]"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], ")"}]}]}],
              ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"3", "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
           ")"}]}], ",", "0", ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"16", "*", 
            RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
            RowBox[{"m", "[", "1", "]"}], "*", 
            RowBox[{
             RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", "*", "\[Sigma]", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], "^", 
                "2"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], ")"}]}], 
              "+", 
              RowBox[{"3", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
               RowBox[{"m", "[", "2", "]"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}]}],
                  "-", 
                 RowBox[{"4", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                  "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                 RowBox[{"4", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}],
                  "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "3"}]}]}], ")"}]}], "+", 
              RowBox[{"2", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "3"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                   "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"9", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"9", "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
           ")"}]}], ",", "0", ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "16"}], "*", 
            RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
            RowBox[{"m", "[", "1", "]"}], "*", 
            RowBox[{
             RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], "*", "\[Sigma]", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], "^", 
                "2"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"9", "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}]}],
                  "-", 
                 RowBox[{"10", "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                  "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                 RowBox[{"3", "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}],
                  "+", 
                 RowBox[{"12", "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "3"}]}]}], ")"}]}], "-", 
              RowBox[{"3", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
               RowBox[{"m", "[", "2", "]"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"12", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}]}],
                  "-", 
                 RowBox[{"12", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                  "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                 RowBox[{"12", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}],
                  "-", 
                 RowBox[{"12", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}],
                  "+", 
                 RowBox[{"12", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}],
                  "+", 
                 RowBox[{"5", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "5"}]}]}], ")"}]}], "-", 
              RowBox[{"6", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "10"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                   "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"15", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "5"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"45", "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
           ")"}]}], ",", "0", ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "16"}], "*", 
            RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
            RowBox[{"m", "[", "1", "]"}], "*", 
            RowBox[{
             RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"60", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
              "-", 
              RowBox[{"120", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
              "+", 
              RowBox[{"32", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
              "-", 
              RowBox[{"64", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
              "-", 
              RowBox[{"32", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
              "+", 
              RowBox[{"64", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
              "+", 
              RowBox[{"32", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
              "-", 
              RowBox[{"64", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
              "-", 
              RowBox[{"32", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
              "+", 
              RowBox[{"64", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
              "+", 
              RowBox[{"32", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
              "-", 
              RowBox[{"64", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
              "+", 
              RowBox[{"220", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
              "-", 
              RowBox[{"440", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
              "+", 
              RowBox[{"120", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
              "-", 
              RowBox[{"240", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
              "-", 
              RowBox[{"5", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
               RowBox[{"m", "[", "2", "]"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"12", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}]}],
                  "-", 
                 RowBox[{"12", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                  "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                 RowBox[{"12", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}],
                  "-", 
                 RowBox[{"12", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}],
                  "+", 
                 RowBox[{"12", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}],
                  "-", 
                 RowBox[{"12", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}],
                  "+", 
                 RowBox[{"12", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}],
                  "+", 
                 RowBox[{"7", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "7"}]}]}], ")"}]}], "-", 
              RowBox[{"10", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "21"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                   "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"21", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "7"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"105", "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
           ")"}]}], ",", "0", ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "16"}], "*", 
            RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
            RowBox[{"m", "[", "1", "]"}], "*", 
            RowBox[{
             RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"84", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}], 
               "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
              "-", 
              RowBox[{"168", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}], 
               "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
              "+", 
              RowBox[{"32", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
              "-", 
              RowBox[{"64", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
              "-", 
              RowBox[{"32", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
              "+", 
              RowBox[{"64", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
              "+", 
              RowBox[{"32", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
              "-", 
              RowBox[{"64", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
              "-", 
              RowBox[{"32", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
              "+", 
              RowBox[{"64", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
              "+", 
              RowBox[{"32", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
              "-", 
              RowBox[{"64", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
              "-", 
              RowBox[{"32", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
              "+", 
              RowBox[{"64", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
              "+", 
              RowBox[{"32", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
              "-", 
              RowBox[{"64", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
              "+", 
              RowBox[{"364", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "10"}]}], 
              "-", 
              RowBox[{"728", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "10"}]}], 
              "+", 
              RowBox[{"224", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "11"}]}], 
              "-", 
              RowBox[{"448", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "11"}]}], 
              "-", 
              RowBox[{"21", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
               RowBox[{"m", "[", "2", "]"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}]}],
                  "-", 
                 RowBox[{"4", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                  "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                 RowBox[{"4", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}],
                  "-", 
                 RowBox[{"4", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}],
                  "+", 
                 RowBox[{"4", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}],
                  "-", 
                 RowBox[{"4", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}],
                  "+", 
                 RowBox[{"4", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}],
                  "-", 
                 RowBox[{"4", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}],
                  "+", 
                 RowBox[{"4", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}],
                  "+", 
                 RowBox[{"3", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "9"}]}]}], ")"}]}], "-", 
              RowBox[{"14", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "36"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                   "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"27", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "9"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"189", "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}], "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "10"}]}], 
           ")"}]}]}], "}"}], ",", "0", ",", "9", ",", "1"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"16", "*", 
          RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", "*", 
              RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "^", "2"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ArcSinh", "[", 
             RowBox[{"p", "/", 
              RowBox[{"m", "[", "1", "]"}]}], "]"}], "+", 
            RowBox[{"ArcSinh", "[", 
             RowBox[{"p", "/", 
              RowBox[{"m", "[", "2", "]"}]}], "]"}]}], ")"}], "*", 
          RowBox[{
           RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
          RowBox[{
           RowBox[{"m", "[", "2", "]"}], "^", "4"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"p", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
            RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}], ")"}]}], 
       ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"16", "*", 
          RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", "*", 
              RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "^", "2"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ArcSinh", "[", 
             RowBox[{"p", "/", 
              RowBox[{"m", "[", "1", "]"}]}], "]"}], "+", 
            RowBox[{"ArcSinh", "[", 
             RowBox[{"p", "/", 
              RowBox[{"m", "[", "2", "]"}]}], "]"}]}], ")"}], "*", 
          RowBox[{
           RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
          RowBox[{
           RowBox[{"m", "[", "2", "]"}], "^", "4"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"p", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
            RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}], 
         ")"}]}]}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.793441047639626*^9, 3.79344104874785*^9}, {
  3.793442763669866*^9, 
  3.793442778830117*^9}},ExpressionUUID->"179c678e-fbba-400c-8514-\
978fbb2f7709"]
}, Closed]],

Cell[CellGroupData[{

Cell["simplified", "Subsubsection",
 CellChangeTimes->{{3.793440786447853*^9, 
  3.793440787404768*^9}},ExpressionUUID->"fe0c4fac-6882-43ab-994f-\
cec70b556ba9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"outS", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SeriesData", "[", 
        RowBox[{"p", ",", "0", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"16", "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "3"}], "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                   "-", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "4"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"15", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                   "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], ")"}]}], "+", 
                RowBox[{"4", "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"165", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                   "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "-", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], ")"}]}], "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"70", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "6"}]}], "+", 
                   RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                   RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "-", 
                   RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{"5", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"15", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"1953", "*", "\[Sigma]", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{"m", "[", "1", "]"}], "*", 
                  RowBox[{"m", "[", "2", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "-", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], ")"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], ")"}]}], "+", 
                 RowBox[{"64", "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "7"}], "+", 
                    RowBox[{"98", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "8"}]}], "+", 
                    RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                    RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "-", 
                    RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                    RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "-", 
                    RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                    RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "+", 
                    RowBox[{"7", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}]}], ")"}]}]}], ")"}]}], ")"}]}], "/", 
            RowBox[{"(", 
             RowBox[{"84", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"1737", "*", "\[Sigma]", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{"m", "[", "1", "]"}], "*", 
                  RowBox[{"m", "[", "2", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}],
                     "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "-", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "10"}]}], ")"}]}], "+", 
                 RowBox[{"128", "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"42", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "10"}]}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "-", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}], "+", 
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "10"}]}]}], ")"}]}]}], ")"}]}], ")"}]}], "/", 
            RowBox[{"(", 
             RowBox[{"72", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "11"}], "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "11"}]}], 
             ")"}]}]}], "}"}], ",", "0", ",", "9", ",", "1"}], "]"}], ",", 
       RowBox[{"SeriesData", "[", 
        RowBox[{"p", ",", "0", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "2"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "4"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"5", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}]}], 
                "+", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "-", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
                "+", 
                RowBox[{"5", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "6"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"15", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"7", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}]}], 
                "+", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "-", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
                "-", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
                "+", 
                RowBox[{"12", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
                "+", 
                RowBox[{"7", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "8"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"21", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}]}],
                 "+", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "-", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
                "-", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
                "+", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
                "-", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
                "+", 
                RowBox[{"4", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
                "+", 
                RowBox[{"3", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "10"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"9", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}], "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "10"}]}], 
             ")"}]}]}], "}"}], ",", "0", ",", "9", ",", "1"}], "]"}]}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SeriesData", "[", 
        RowBox[{"p", ",", "0", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"16", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "^", "2"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], ")"}]}],
                 "+", 
                RowBox[{"16", "*", "\[Sigma]", "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "7"}], "+", 
                    RowBox[{"16", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], ")"}]}],
                 "+", 
                RowBox[{"3", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "-", 
                   RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], "*", 
              
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"m", "[", "1", "]"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"128", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "3"}]}], "-", 
                RowBox[{"128", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "3"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], ")"}]}],
                 "-", 
                RowBox[{"32", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"4", "-", 
                    RowBox[{"12", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}], "+", 
                    RowBox[{"16", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}]}], ")"}]}], "+", 
                RowBox[{"9", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "5"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], 
                    ")"}]}]}], ")"}]}], "-", 
                RowBox[{"32", "*", "\[Sigma]", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "3"}]}], ")"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "7"}], "+", 
                    RowBox[{"16", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "4"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "27"}], "+", 
                    RowBox[{"64", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"9", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}], "*", 
              
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"m", "[", "1", "]"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "3"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                   "-", 
                   RowBox[{"3", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}], "-", 
                RowBox[{"512", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "3"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "3"}]}], "-", 
                   RowBox[{"2", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                   RowBox[{"3", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"12", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}]}], ")"}]}], "-", 
                RowBox[{"384", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "6"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "-", 
                    RowBox[{"20", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}], "+", 
                    RowBox[{"24", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{"5", "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}]}], ")"}]}], "-", 
                RowBox[{"45", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"22", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "-", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"81", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                    RowBox[{"49", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], 
                    ")"}]}]}], ")"}]}], "-", 
                RowBox[{"128", "*", "\[Sigma]", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "10"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "8"}]}], "-", 
                   RowBox[{"30", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "41"}], "+", 
                    RowBox[{"96", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "-", 
                    RowBox[{"10", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}], "+", 
                   RowBox[{"15", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "7"}], "+", 
                    RowBox[{"16", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "-", 
                    RowBox[{"2", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"180", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}], "*", 
              
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"m", "[", "1", "]"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2048", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "3"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                   "-", 
                   RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{"10", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{"15", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}]}], ")"}]}], "-", 
                RowBox[{"2048", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "3"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"5", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "5"}]}], "-", 
                   RowBox[{"6", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"4", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "-", 
                   RowBox[{"15", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{"30", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}]}], ")"}]}], "-", 
                RowBox[{"2560", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "8"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"8", "-", 
                    RowBox[{"28", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}], "+", 
                    RowBox[{"32", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "+", 
                   RowBox[{"7", "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}]}], ")"}]}], "-", 
                RowBox[{"105", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"93", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "-", 
                   RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"221", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                    RowBox[{"157", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], 
                    ")"}]}]}], ")"}]}], "-", 
                RowBox[{"2560", "*", "\[Sigma]", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "7"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "10"}]}], "-", 
                   RowBox[{"21", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "55"}], "+", 
                    RowBox[{"128", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "-", 
                    RowBox[{"7", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}], "+", 
                   RowBox[{"7", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "7"}], "+", 
                    RowBox[{"16", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "-", 
                    RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"1680", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}], "*", 
              
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
               RowBox[{"m", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"8192", "*", "\[Sigma]", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                  RowBox[{"m", "[", "2", "]"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                   "^", "3"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"7", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "7"}]}], "-", 
                    RowBox[{"10", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"9", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{"4", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "-", 
                    RowBox[{"5", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                    RowBox[{"18", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "-", 
                    RowBox[{"35", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                    RowBox[{"56", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}]}], ")"}]}], "-", 
                 RowBox[{"16384", "*", 
                  RowBox[{
                   RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}], 
                  "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                    "+", 
                    RowBox[{"36", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "+", 
                    RowBox[{"63", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "+", 
                    RowBox[{"28", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}]}], ")"}]}], "+", 
                 RowBox[{"14336", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                  RowBox[{
                   RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                  "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "10"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "10"}], "+", 
                    RowBox[{"20", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}], "+", 
                    RowBox[{"9", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "10"}]}]}], ")"}]}], "-", 
                 RowBox[{"189", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{"m", "[", "1", "]"}], "*", 
                  RowBox[{
                   RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}], 
                  "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "386"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2245", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                    RowBox[{"1733", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], 
                    ")"}]}]}], ")"}]}], "+", 
                 RowBox[{"14336", "*", "\[Sigma]", "*", 
                  RowBox[{
                   RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "12"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "12"}]}], "-", 
                    RowBox[{"36", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "11"}],
                     "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "10"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "69"}], "+", 
                    RowBox[{"160", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "-", 
                    RowBox[{"12", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}], "+", 
                    RowBox[{"9", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}],
                     "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "7"}], "+", 
                    RowBox[{"16", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}]}], "-", 
                    RowBox[{"4", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}]}], ")"}]}], "+", 
                 RowBox[{"8192", "*", 
                  RowBox[{
                   RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                  "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"36", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}], "+", 
                    RowBox[{"63", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "10"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], ")"}]}], "+", 
                    RowBox[{"7", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}], 
                    "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "2"}]}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}]}], "/", 
            RowBox[{"(", 
             RowBox[{"12096", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}], "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "11"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}], 
             ")"}]}]}], "}"}], ",", "0", ",", "9", ",", "1"}], "]"}], ",", 
       RowBox[{"SeriesData", "[", 
        RowBox[{"p", ",", "0", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"16", "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "-", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "4"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "^", "2"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], ")"}]}],
                 "+", 
                RowBox[{"2", "*", "\[Sigma]", "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], 
                  ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"16", "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"m", "[", "1", "]"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "-", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], ")"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "2"}]}], "+", 
                RowBox[{"8", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "2"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}]}], ")"}]}], "+", 
                RowBox[{"4", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}]}], ")"}]}], "-", 
                   RowBox[{
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "-", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], ")"}]}]}], ")"}]}], "-", 
                RowBox[{"2", "*", "\[Sigma]", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}]}], "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"9", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"16", "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"m", "[", "1", "]"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"8", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "2"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                   "-", 
                   RowBox[{"3", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}], "-", 
                RowBox[{"12", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "2"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                   "-", 
                   RowBox[{"2", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"3", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{"4", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}]}], ")"}]}], "+", 
                RowBox[{"3", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{"5", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}]}], ")"}]}], "+", 
                RowBox[{"4", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "-", 
                    RowBox[{"3", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}], ")"}]}], "-", 
                   RowBox[{"3", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], ")"}]}]}], ")"}]}], "+", 
                RowBox[{"2", "*", "\[Sigma]", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "10"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}]}], "+", 
                   RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "5"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"45", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"16", "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"m", "[", "1", "]"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"8", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "2"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                   "-", 
                   RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{"10", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{"15", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}]}], ")"}]}], "-", 
                RowBox[{"20", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                   "-", 
                   RowBox[{"7", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "-", 
                   RowBox[{"6", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}]}], ")"}]}], "+", 
                RowBox[{"5", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "7"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                   RowBox[{"7", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}]}], ")"}]}], "+", 
                RowBox[{"4", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "-", 
                    RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{"10", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{"15", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}]}], ")"}]}], ")"}]}], "-", 
                   RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "-", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], ")"}]}]}], ")"}]}], "+", 
                RowBox[{"10", "*", "\[Sigma]", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "7"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"7", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "7"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"105", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"16", "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"m", "[", "1", "]"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"8", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                  "^", "2"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                   "-", 
                   RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{"10", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{"15", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "-", 
                   RowBox[{"21", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{"28", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}]}], ")"}]}], "-", 
                RowBox[{"28", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                   "-", 
                   RowBox[{"9", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "-", 
                   RowBox[{"8", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}]}], ")"}]}], "+", 
                RowBox[{"7", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "9"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "+", 
                   RowBox[{"9", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}]}], ")"}]}], "+", 
                RowBox[{"4", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "7"}], "*", 
                    RowBox[{"\[Sigma]", "^", "2"}], "*", 
                    RowBox[{
                    RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "-", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], ")"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], ")"}]}], "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "-", 
                    RowBox[{"3", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                    RowBox[{"6", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                    RowBox[{"10", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{"15", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "-", 
                    RowBox[{"21", "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                    RowBox[{"28", "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}]}], ")"}]}]}], ")"}]}], "+", 
                RowBox[{"14", "*", "\[Sigma]", "*", 
                 RowBox[{
                  RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "12"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                    "^", "2"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "9"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"189", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}], "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "10"}]}], 
             ")"}]}]}], "}"}], ",", "0", ",", "9", ",", "1"}], "]"}]}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SeriesData", "[", 
        RowBox[{"p", ",", "0", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"8", "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                   "-", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], ")"}]}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"25", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"25", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"15", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                   "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], ")"}]}], "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"25", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"25", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"165", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                   "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "-", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], ")"}]}], "+", 
                RowBox[{"16", "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"5", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"25", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "6"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{"5", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"25", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"15", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"1953", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                   "-", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], ")"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                   "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], ")"}]}], "+", 
                RowBox[{"128", "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"7", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"25", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "8"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "+", 
                   RowBox[{"7", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"25", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"168", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "1536"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "11"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                RowBox[{"19200", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "11"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "-", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "-", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
                "-", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
                "-", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
                "+", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
                "+", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
                "-", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
                "-", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
                "+", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
                "+", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
                "-", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
                "-", 
                RowBox[{"512", "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "10"}]}],
                 "+", 
                RowBox[{"2560", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "10"}]}],
                 "-", 
                RowBox[{"1536", "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "11"}]}],
                 "+", 
                RowBox[{"19200", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "11"}]}],
                 "+", 
                RowBox[{"1737", "*", "\[Sigma]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{"m", "[", "1", "]"}], "*", 
                 RowBox[{"m", "[", "2", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}],
                    "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "-", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "+", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "-", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}], "+", 
                   RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "10"}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"144", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "11"}], "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "11"}]}], 
             ")"}]}]}], "}"}], ",", "0", ",", "9", ",", "1"}], "]"}], ",", 
       RowBox[{"SeriesData", "[", 
        RowBox[{"p", ",", "0", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "2"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "4"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "5"}], "+", 
                   RowBox[{"70", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}]}], 
                "+", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "-", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
                "+", 
                RowBox[{"5", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "6"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"15", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "7"}], "+", 
                   RowBox[{"98", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}]}], 
                "+", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "-", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
                "-", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
                "+", 
                RowBox[{"24", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
                "+", 
                RowBox[{"7", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "8"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"21", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], "*", 
              
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
             ")"}]}], ",", "0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "16"}], "*", 
              RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
              RowBox[{
               RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", 
                   RowBox[{"42", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}]}],
                 "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                 "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
                "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
                "-", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
                "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
                "-", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
                "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
                "-", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                 "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
                "+", 
                RowBox[{"8", "*", 
                 RowBox[{"\[Sigma]", "^", "2"}], "*", 
                 RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
                "+", 
                RowBox[{"3", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"14", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                  "10"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"9", "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}], "*", 
              RowBox[{
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "10"}]}], 
             ")"}]}]}], "}"}], ",", "0", ",", "9", ",", "1"}], "]"}]}], "}"}],
      ",", 
     RowBox[{"SeriesData", "[", 
      RowBox[{"p", ",", "0", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"16", "*", 
            RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
            RowBox[{
             RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
            RowBox[{
             RowBox[{"m", "[", "2", "]"}], "^", "4"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
               RowBox[{"m", "[", "1", "]"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"12", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], ")"}]}], 
              "+", 
              RowBox[{"2", "*", "\[Sigma]", "*", 
               RowBox[{"m", "[", "2", "]"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], ")"}]}]}],
              ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"3", "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
           ")"}]}], ",", "0", ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"16", "*", 
            RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
            RowBox[{"m", "[", "1", "]"}], "*", 
            RowBox[{
             RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", "*", "\[Sigma]", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], "^", 
                "2"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}]}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}]}], ")"}]}], 
              "+", 
              RowBox[{"3", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
               RowBox[{"m", "[", "2", "]"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}]}],
                  "-", 
                 RowBox[{"4", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                  "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                 RowBox[{"4", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}],
                  "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "3"}]}]}], ")"}]}], "+", 
              RowBox[{"2", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "3"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                   "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"9", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "3"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"9", "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
           ")"}]}], ",", "0", ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"16", "*", 
            RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
            RowBox[{"m", "[", "1", "]"}], "*", 
            RowBox[{
             RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", "*", "\[Sigma]", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], "^", 
                "2"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"9", "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}]}],
                  "-", 
                 RowBox[{"10", "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                  "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                 RowBox[{"3", "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}],
                  "+", 
                 RowBox[{"12", "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "3"}]}]}], ")"}]}], "+", 
              RowBox[{"3", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
               RowBox[{"m", "[", "2", "]"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"12", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}]}],
                  "-", 
                 RowBox[{"12", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                  "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                 RowBox[{"12", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}],
                  "-", 
                 RowBox[{"12", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}],
                  "+", 
                 RowBox[{"12", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}],
                  "+", 
                 RowBox[{"5", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "5"}]}]}], ")"}]}], "+", 
              RowBox[{"6", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "10"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                   "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"15", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "5"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"45", "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
           ")"}]}], ",", "0", ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"16", "*", 
            RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
            RowBox[{"m", "[", "1", "]"}], "*", 
            RowBox[{
             RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "60"}], "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
              "+", 
              RowBox[{"120", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
              "-", 
              RowBox[{"32", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
              "+", 
              RowBox[{"64", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
              "+", 
              RowBox[{"32", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
              "-", 
              RowBox[{"64", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
              "-", 
              RowBox[{"32", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
              "+", 
              RowBox[{"64", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
              "+", 
              RowBox[{"32", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
              "-", 
              RowBox[{"64", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
              "-", 
              RowBox[{"32", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
              "+", 
              RowBox[{"64", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
              "-", 
              RowBox[{"220", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
              "+", 
              RowBox[{"440", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
              "-", 
              RowBox[{"120", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
              "+", 
              RowBox[{"240", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
              "+", 
              RowBox[{"5", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
               RowBox[{"m", "[", "2", "]"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"12", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}]}],
                  "-", 
                 RowBox[{"12", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                  "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                 RowBox[{"12", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}],
                  "-", 
                 RowBox[{"12", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}],
                  "+", 
                 RowBox[{"12", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}],
                  "-", 
                 RowBox[{"12", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}],
                  "+", 
                 RowBox[{"12", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}],
                  "+", 
                 RowBox[{"7", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "7"}]}]}], ")"}]}], "+", 
              RowBox[{"10", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "21"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                   "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"21", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "7"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"105", "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
           ")"}]}], ",", "0", ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"16", "*", 
            RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
            RowBox[{"m", "[", "1", "]"}], "*", 
            RowBox[{
             RowBox[{"m", "[", "2", "]"}], "^", "3"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "84"}], "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}], 
               "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
              "+", 
              RowBox[{"168", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}], 
               "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}], 
              "-", 
              RowBox[{"32", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
              "+", 
              RowBox[{"64", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}], 
              "+", 
              RowBox[{"32", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
              "-", 
              RowBox[{"64", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}], 
              "-", 
              RowBox[{"32", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
              "+", 
              RowBox[{"64", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}], 
              "+", 
              RowBox[{"32", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
              "-", 
              RowBox[{"64", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}], 
              "-", 
              RowBox[{"32", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
              "+", 
              RowBox[{"64", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}], 
              "+", 
              RowBox[{"32", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
              "-", 
              RowBox[{"64", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}], 
              "-", 
              RowBox[{"32", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
              "+", 
              RowBox[{"64", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "9"}]}], 
              "-", 
              RowBox[{"364", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "10"}]}], 
              "+", 
              RowBox[{"728", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "10"}]}], 
              "-", 
              RowBox[{"224", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "11"}]}], 
              "+", 
              RowBox[{"448", "*", 
               RowBox[{"\[Sigma]", "^", "3"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
               RowBox[{
                RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "11"}]}], 
              "+", 
              RowBox[{"21", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
               RowBox[{
                RowBox[{"m", "[", "1", "]"}], "^", "3"}], "*", 
               RowBox[{"m", "[", "2", "]"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}]}],
                  "-", 
                 RowBox[{"4", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                  "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "+", 
                 RowBox[{"4", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "2"}]}],
                  "-", 
                 RowBox[{"4", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "3"}]}],
                  "+", 
                 RowBox[{"4", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "4"}]}],
                  "-", 
                 RowBox[{"4", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "5"}]}],
                  "+", 
                 RowBox[{"4", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "6"}]}],
                  "-", 
                 RowBox[{"4", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "7"}]}],
                  "+", 
                 RowBox[{"4", "*", 
                  RowBox[{"\[Sigma]", "^", "2"}], "*", 
                  RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "8"}]}],
                  "+", 
                 RowBox[{"3", "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                   "9"}]}]}], ")"}]}], "+", 
              RowBox[{"14", "*", "\[Sigma]", "*", 
               RowBox[{
                RowBox[{"m", "[", "2", "]"}], "^", "2"}], "*", 
               RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "36"}], "*", 
                  RowBox[{
                   RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "9"}], 
                  "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}], 
                   "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"m", "[", "1", "]"}], "^", "2"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"27", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", 
                    "9"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "8"}], 
                    "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "7"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "2"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "6"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "3"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "5"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "4"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "4"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "5"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "3"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "6"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "2"}], 
                    "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "7"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "8"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", "*", 
                    RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "*", 
                    RowBox[{
                    RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", 
                    "9"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"189", "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "^", "10"}], "*", 
            RowBox[{
             RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}], "^", "10"}]}], 
           ")"}]}]}], "}"}], ",", "0", ",", "9", ",", "1"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"16", "*", 
          RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", "*", 
              RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "^", "2"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ArcSinh", "[", 
             RowBox[{"p", "/", 
              RowBox[{"m", "[", "1", "]"}]}], "]"}], "+", 
            RowBox[{"ArcSinh", "[", 
             RowBox[{"p", "/", 
              RowBox[{"m", "[", "2", "]"}]}], "]"}]}], ")"}], "*", 
          RowBox[{
           RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
          RowBox[{
           RowBox[{"m", "[", "2", "]"}], "^", "4"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"p", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
            RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}], ")"}]}], 
       ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"16", "*", 
          RowBox[{"G", "^", "3"}], "*", "Pi", "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", "*", 
              RowBox[{"\[Sigma]", "^", "2"}]}]}], ")"}], "^", "2"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ArcSinh", "[", 
             RowBox[{"p", "/", 
              RowBox[{"m", "[", "1", "]"}]}], "]"}], "+", 
            RowBox[{"ArcSinh", "[", 
             RowBox[{"p", "/", 
              RowBox[{"m", "[", "2", "]"}]}], "]"}]}], ")"}], "*", 
          RowBox[{
           RowBox[{"m", "[", "1", "]"}], "^", "4"}], "*", 
          RowBox[{
           RowBox[{"m", "[", "2", "]"}], "^", "4"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"p", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[CapitalEpsilon]", "[", "1", "]"}], "+", 
            RowBox[{"\[CapitalEpsilon]", "[", "2", "]"}]}], ")"}]}], 
         ")"}]}]}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7934410508484383`*^9, 3.793441051218684*^9}, {
  3.793443092551833*^9, 
  3.79344309377355*^9}},ExpressionUUID->"aa333b99-37df-4586-a5e7-\
d8262d58a5df"]
}, Closed]]
},
WindowSize->{808, 847},
WindowMargins->{{43, Automatic}, {Automatic, 24}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 86, 0, 45, "Subsubsection",ExpressionUUID->"29c7a69c-6561-4a54-a5c0-599485cb274d"],
Cell[669, 24, 1068, 24, 288, "Text",ExpressionUUID->"802ea981-f6ca-46fd-8863-edda4aa8ea49"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1774, 53, 161, 3, 45, "Subsubsection",ExpressionUUID->"507a8c47-6125-4b43-8750-b07a1410f3c4"],
Cell[1938, 58, 239751, 5502, 7003, "Input",ExpressionUUID->"28a02281-ac94-4bfa-aa89-463b0cddc958"]
}, Closed]],
Cell[CellGroupData[{
Cell[241726, 5565, 161, 3, 37, "Subsubsection",ExpressionUUID->"8cdeed82-5ad7-4c21-a90b-3e7cdc63ee0c"],
Cell[241890, 5570, 270918, 6200, 7570, "Input",ExpressionUUID->"179c678e-fbba-400c-8514-978fbb2f7709"]
}, Closed]],
Cell[CellGroupData[{
Cell[512845, 11775, 161, 3, 37, "Subsubsection",ExpressionUUID->"fe0c4fac-6882-43ab-994f-cec70b556ba9"],
Cell[513009, 11780, 252212, 5808, 7024, "Input",ExpressionUUID->"aa333b99-37df-4586-a5e7-d8262d58a5df"]
}, Closed]]
}
]
*)

